You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@lucy.apache.org by ma...@apache.org on 2011/07/06 20:06:41 UTC

[lucy-commits] svn commit: r1143514 - in /incubator/lucy/trunk/clownfish/lib/Clownfish/Binding: Core.pm Core/Class.pm Core/File.pm Perl.pm

Author: marvin
Date: Wed Jul  6 18:06:41 2011
New Revision: 1143514

URL: http://svn.apache.org/viewvc?rev=1143514&view=rev
Log:
Rename an autogenerated file.

Change the name of the autogenerated header file containing the "typedef
struct" declarations for all classes within a Clownfish parcel from "boil.h"
(a legacy of the Clownfish's old name, "Boilerplater"), to "parcel.h".  It's
still not ideal, as it should be named after the parcel itself, but we'll
cross that bridge later.

Modified:
    incubator/lucy/trunk/clownfish/lib/Clownfish/Binding/Core.pm
    incubator/lucy/trunk/clownfish/lib/Clownfish/Binding/Core/Class.pm
    incubator/lucy/trunk/clownfish/lib/Clownfish/Binding/Core/File.pm
    incubator/lucy/trunk/clownfish/lib/Clownfish/Binding/Perl.pm

Modified: incubator/lucy/trunk/clownfish/lib/Clownfish/Binding/Core.pm
URL: http://svn.apache.org/viewvc/incubator/lucy/trunk/clownfish/lib/Clownfish/Binding/Core.pm?rev=1143514&r1=1143513&r2=1143514&view=diff
==============================================================================
--- incubator/lucy/trunk/clownfish/lib/Clownfish/Binding/Core/Class.pm (original)
+++ incubator/lucy/trunk/clownfish/lib/Clownfish/Binding/Core/Class.pm Wed Jul  6 18:06:41 2011
@@ -72,7 +72,7 @@ sub to_c_header {
     if ( $client->inert ) {
         return <<END_INERT
 #include "charmony.h"
-#include "boil.h"
+#include "parcel.h"
 $parent_include
 
 /* Declare this class's inert variables.
@@ -97,7 +97,7 @@ END_INERT
     return <<END_STUFF;
 
 #include "charmony.h"
-#include "boil.h"
+#include "parcel.h"
 
 /* Include the header for this class's parent. 
  */

Modified: incubator/lucy/trunk/clownfish/lib/Clownfish/Binding/Core/File.pm
URL: http://svn.apache.org/viewvc/incubator/lucy/trunk/clownfish/lib/Clownfish/Binding/Core/File.pm?rev=1143514&r1=1143513&r2=1143514&view=diff
==============================================================================
--- incubator/lucy/trunk/clownfish/lib/Clownfish/Binding/Core/File.pm (original)
+++ incubator/lucy/trunk/clownfish/lib/Clownfish/Binding/Core/File.pm Wed Jul  6 18:06:41 2011
@@ -136,7 +136,7 @@ $args{header}
 $c_file_syms
 #define C_LUCY_VTABLE
 #define C_LUCY_ZOMBIECHARBUF
-#include "boil.h"
+#include "parcel.h"
 #include "Lucy/Object/VTable.h"
 #include "Lucy/Object/CharBuf.h"
 #include "Lucy/Object/Err.h"

Modified: incubator/lucy/trunk/clownfish/lib/Clownfish/Binding/Perl.pm
URL: http://svn.apache.org/viewvc/incubator/lucy/trunk/clownfish/lib/Clownfish/Binding/Perl.pm?rev=1143514&r1=1143513&r2=1143514&view=diff
==============================================================================
--- incubator/lucy/trunk/clownfish/lib/Clownfish/Binding/Perl.pm (original)
+++ incubator/lucy/trunk/clownfish/lib/Clownfish/Binding/Perl.pm Wed Jul  6 18:06:41 2011
@@ -193,7 +193,7 @@ sub _xs_file_contents {
  */
 
 #include "XSBind.h"
-#include "boil.h"
+#include "parcel.h"
 #include "$self->{boot_h_file}"
 
 #include "Lucy/Object/Host.h"
@@ -400,7 +400,7 @@ $self->{header}
 #include "perl.h"
 #include "XSUB.h"
 #include "$self->{boot_h_file}"
-#include "boil.h"
+#include "parcel.h"
 $pound_includes
 
 void
--- incubator/lucy/trunk/clownfish/lib/Clownfish/Binding/Core.pm (original)
+++ incubator/lucy/trunk/clownfish/lib/Clownfish/Binding/Core.pm Wed Jul  6 18:06:41 2011
@@ -76,15 +76,15 @@ sub write_all_modified {
         );
     }
 
-    # If any class definition changed, rewrite the boil.h file.
-    $self->_write_boil_h if $modified;
+    # If any class definition changed, rewrite the parcel.h file.
+    $self->_write_parcel_h if $modified;
 
     return $modified;
 }
 
 # Write the "boil.h" header file, which contains common symbols needed by all
 # classes, plus typedefs for all class structs.
-sub _write_boil_h {
+sub _write_parcel_h {
     my $self     = shift;
     my $ordered  = $self->{hierarchy}->ordered_classes;
     my $typedefs = "";
@@ -99,7 +99,7 @@ sub _write_boil_h {
     # Create Clownfish aliases if necessary.
     my $aliases = Clownfish::Binding::Core::Aliases->c_aliases;
 
-    my $filepath = catfile( $self->{dest}, "boil.h" );
+    my $filepath = catfile( $self->{dest}, "parcel.h" );
     unlink $filepath;
     sysopen( my $fh, $filepath, O_CREAT | O_EXCL | O_WRONLY )
         or confess("Can't open '$filepath': $!");
@@ -76,15 +76,15 @@ sub write_all_modified {
 }
 
-# Write the "boil.h" header file, which contains common symbols needed by all
+# Write the "parcel.h" header file, which contains common symbols needed by all
 # classes, plus typedefs for all class structs.

Modified: incubator/lucy/trunk/clownfish/lib/Clownfish/Binding/Core/Class.pm
URL: http://svn.apache.org/viewvc/incubator/lucy/trunk/clownfish/lib/Clownfish/Binding/Core/Class.pm?rev=1143514&r1=1143513&r2=1143514&view=diff
==============================================================================